@@ -66,6 +66,14 @@ couchdb_new (const char *hostname)
 	return couchdb;
 }
 
+const char *
+couchdb_get_hostname (CouchDB *couchdb)
+{
+	g_return_val_if_fail (COUCHDB_IS (couchdb), NULL);
+
+	return (const char *) couchdb->hostname;
+}
+
 GSList *
 couchdb_list_databases (CouchDB *couchdb, GError **error)
 {
